==> python2.2_2.2.3dfsg.orig.tar.gz: python2.2-2.2.3dfsg.orig/Modules/md5.h <==
/*
 * This is the header file for the MD5 message-digest algorithm.
 * The algorithm is due to Ron Rivest.  This code was
 * written by Colin Plumb in 1993, no copyright is claimed.
 * This code is in the public domain; do with it what you wish.
 *
 * Equivalent code is available from RSA Data Security, Inc.
 * This code has been tested against that, and is equivalent,
 * except that you don't need to include two pages of legalese
 * with every copy.
 *
 * To compute the message digest of a chunk of bytes, declare an
 * MD5Context structure, pass it to MD5Init, call MD5Update as
 * needed on buffers full of bytes, and then call MD5Final, which
 * will fill a supplied 16-byte array with the digest.
 *
 * Changed so as no longer to depend on Colin Plumb's `usual.h'
 * header definitions; now uses stuff from dpkg's config.h
 *  - Ian Jackson <ian@chiark.greenend.org.uk>.
 * Still in the public domain.
 *
 * Changed to use config stuff from Python.h
 *  - Matthias Klose <m@klose.in-berlin.de>.
 * Still in the public domain.
 */

#ifndef MD5_H
#define MD5_H

#if SIZEOF_LONG == 4
typedef unsigned long int UWORD32;
#elif SIZEOF_SHORT == 4
typedef unsigned short int UWORD32;
#elif INT_MAX == 2147483647
typedef unsigned int UWORD32;
#else
#error "Can't find a 4-byte integral type"
#endif

#define md5byte unsigned char

struct MD5Context {
	UWORD32 buf[4];
	UWORD32 bytes[2];
	UWORD32 in[16];
};

void MD5Init(struct MD5Context *context);
void MD5Update(struct MD5Context *context, md5byte const *buf, unsigned len);
void MD5Final(unsigned char digest[16], struct MD5Context *context);
void MD5Transform(UWORD32 buf[4], UWORD32 const in[16]);

#endif /* !MD5_H */

==> python2.4_2.4.5.orig.tar.gz: python2.4-2.4.5.orig/Modules/md5.h <==
/*
 * This is the header file for the MD5 message-digest algorithm.
 * The algorithm is due to Ron Rivest.  This code was
 * written by Colin Plumb in 1993, no copyright is claimed.
 * This code is in the public domain; do with it what you wish.
 *
 * Equivalent code is available from RSA Data Security, Inc.
 * This code has been tested against that, and is equivalent,
 * except that you don't need to include two pages of legalese
 * with every copy.
 *
 * To compute the message digest of a chunk of bytes, declare an
 * MD5Context structure, pass it to MD5Init, call MD5Update as
 * needed on buffers full of bytes, and then call MD5Final, which
 * will fill a supplied 16-byte array with the digest.
 *
 * Changed so as no longer to depend on Colin Plumb's `usual.h'
 * header definitions; now uses stuff from dpkg's config.h
 *  - Ian Jackson <ian@chiark.greenend.org.uk>.
 * Still in the public domain.
 *
 * Changed to use config stuff from Python.h
 *  - Matthias Klose <m@klose.in-berlin.de>.
 * Still in the public domain.
 */

#ifndef MD5_H
#define MD5_H

#if SIZEOF_LONG == 4
typedef unsigned long int UWORD32;
#elif SIZEOF_SHORT == 4
typedef unsigned short int UWORD32;
#elif INT_MAX == 2147483647
typedef unsigned int UWORD32;
#else
#error "Can't find a 4-byte integral type"
#endif

#define md5byte unsigned char

struct MD5Context {
	UWORD32 buf[4];
	UWORD32 bytes[2];
	UWORD32 in[16];
};

/* Rename all exported symbols to avoid conflicts with similarly named
   symbols in other libraries */

#define MD5Init _PyDFSG_MD5Init
#define MD5Update _PyDFSG_MD5Update
#define MD5Final _PyDFSG_MD5Final
#define MD5Transform _PyDFSG_MD5Transform

void MD5Init(struct MD5Context *context);
void MD5Update(struct MD5Context *context, md5byte const *buf, unsigned len);
void MD5Final(unsigned char digest[16], struct MD5Context *context);
void MD5Transform(UWORD32 buf[4], UWORD32 const in[16]);

#endif /* !MD5_H */
